@@ -79,6 +79,10 @@ class TestSimpleModule(object):
         # "self" should not be included in constructor arguments
         assert "Foo(self" not in example_file
 
+        # Overridden methods without their own docstring
+        # should inherit the parent's docstring
+        assert example_file.count("This method should parse okay") == 2
+
         assert not os.path.exists("_build/text/autoapi/method_multiline")
 
         index_path = "_build/text/index.txt"
@@ -229,26 +233,6 @@ class TestPositionalOnlyArgumentsModule(object):
         with io.open(example_path, encoding="utf8") as example_handle:
             example_file = example_handle.read()
 
-        # Sphinx 3 incorrectly adds default values
-        if sphinx.version_info >= (3,):
-            assert "f_simple(a, b, /, c, d, *, e=None, f=None)" in example_file
-
-            assert (
-                "f_comment(a: int, b: int, /, c: Optional[int], d: Optional[int], *, e: float = None, f: float = None)"
-                in example_file
-            )
-            assert (
-                "f_annotation(a: int, b: int, /, c: Optional[int], d: Optional[int], *, e: float = None, f: float = None)"
-                in example_file
-            )
-            # Requires unreleased astroid >2.4
-            # assert "f_arg_comment(a: int, b: int, /, c: Optional[int], d: Optional[int], *, e: float, f: float)" in example_file
-            assert (
-                "f_no_cd(a: int, b: int, /, *, e: float = None, f: float = None)"
-                in example_file
-            )
-            return
-
         assert "f_simple(a, b, /, c, d, *, e, f)" in example_file
 
         assert (
@@ -259,8 +243,10 @@ class TestPositionalOnlyArgumentsModule(object):
             "f_annotation(a: int, b: int, /, c: Optional[int], d: Optional[int], *, e: float, f: float)"
             in example_file
         )
-        # Requires unreleased astroid >2.4
-        # assert "f_arg_comment(a: int, b: int, /, c: Optional[int], d: Optional[int], *, e: float, f: float)" in example_file
+        assert (
+            "f_arg_comment(a: int, b: int, /, c: Optional[int], d: Optional[int], *, e: float, f: float)"
+            in example_file
+        )
         assert "f_no_cd(a: int, b: int, /, *, e: float, f: float)" in example_file
 
 
@@ -381,6 +367,29 @@ def test_hiding_inheritance(builder):
     assert "Bases:" not in example_file
 
 
+def test_hiding_imported_members(builder):
+    confoverrides = {"autoapi_options": ["members", "undoc-members"]}
+    builder("pypackagecomplex", confoverrides=confoverrides)
+
+    subpackage_path = "_build/text/autoapi/complex/subpackage/index.txt"
+    with io.open(subpackage_path, encoding="utf8") as subpackage_handle:
+        subpackage_file = subpackage_handle.read()
+
+    assert "Part of a public resolution chain." not in subpackage_file
+
+    package_path = "_build/text/autoapi/complex/index.txt"
+    with io.open(package_path, encoding="utf8") as package_handle:
+        package_file = package_handle.read()
+
+    assert "Part of a public resolution chain." not in package_file
+
+    submodule_path = "_build/text/autoapi/complex/subpackage/submodule/index.txt"
+    with io.open(submodule_path, encoding="utf8") as submodule_handle:
+        submodule_file = submodule_handle.read()
+
+    assert "A private function made public by import." not in submodule_file
+
+
 def test_inherited_members(builder):
     confoverrides = {
         "autoapi_options": ["members", "inherited-members", "undoc-members"]
@@ -412,6 +421,26 @@ def test_skipping_members(builder):
     assert "not ignored" in example_file
 
 
+@pytest.mark.parametrize(
+    "value,order",
+    [
+        ("bysource", ["Foo", "decorator_okay", "Bar"]),
+        ("alphabetical", ["Bar", "Foo", "decorator_okay"]),
+        ("groupwise", ["Bar", "Foo", "decorator_okay"]),
+    ],
+)
+def test_order_members(builder, value, order):
+    confoverrides = {"autoapi_member_order": value}
+    builder("pyexample", confoverrides=confoverrides)
+
+    example_path = "_build/text/autoapi/example/index.txt"
+    with io.open(example_path, encoding="utf8") as example_handle:
+        example_file = example_handle.read()
+
+    indexes = [example_file.index(name) for name in order]
+    assert indexes == sorted(indexes)
+
+
 class _CompareInstanceType(object):
     def __init__(self, type_):
         self.type = type_
